==> apeman-scff-react-2.0.40.tgz: package/ci/tmplify.js <==
#!/usr/bin/env node

/**
 * Tmplify prototype.
 */

'use strict'

process.chdir(`${__dirname}/..`)

const path = require('path')
const fs = require('fs')
const apeTasking = require('ape-tasking')
const tmplconv = require('tmplconv')

const scaffold = require('../lib')

let demo = path.dirname(require.resolve('apeman-demo-react/package.json'))

apeTasking.runTasks('tmplify', [
  () => tmplconv.tmplify(demo, 'asset/tmpl', {
    clean: true,
    mode: '444',
    pattern: [
      '+(bin|lib|test)/.*.bud',
      '+(bin|lib|test)/.*.hbs',
      'test/._test.js.bud',
      'doc/demo/.*.*',
      '**/*.*',
      '.*'
    ],
    ignore: [
      '.DS_Store',
      '.svn',
      '.npmignore',
      '.gitignore',
      'node_modules/**/*.*',
      'node_modules/**/.*',
      'doc/demo/demo.html',
      'doc/demo/demo.js',
      'ci/demo.js',
      'lib/index.js',
      'lib/*.js',
      'README.md',
      'LICENSE'
    ],
    data: {
      'github_repository': 'apeman-demo-labo/apeman-demo-react',
      'package_name': 'apeman-demo-react',
      'package_description': 'Demo of React component.',
      'component_name': 'DemoComponent',
      'author_name': 'okunishinishi',
      'author_email': 'okunishitaka.com@gmail.com',
      'author_url': 'http://okunishitaka.com'
    },
    prefix: scaffold.prefix,
    suffix: scaffold.suffix
  }),
  () => tmplconv.tmplify(__dirname + '/..', 'asset/tmpl', {
    pattern: [
      '.gitignore',
      '.npmignore'
    ],
    prefix: scaffold.prefix,
    suffix: scaffold.suffix
  }),
  (callback) => {
    let filename = require.resolve('../asset/tmpl/package.json.tmpl')
    let str = fs.readFileSync(filename).toString()
    let pkg = JSON.parse(str)
    fs.chmodSync(filename, '644')
    fs.writeFileSync(filename, JSON.stringify({
      name: pkg.name,
      version: '1.0.0',
      description: pkg.description,
      main: pkg.main,
      scripts: pkg.scripts,
      repository: pkg.repository.url.split(/\//g).slice(-1).join('/').replace(/\.git$/, ''),
      keywords: pkg.keywords,
      author: pkg.author,
      license: pkg.license,
      bugs: pkg.bugs,
      homepage: pkg.homepage,
      dependencies: pkg.dependencies,
      devDependencies: pkg.devDependencies,
      engines: pkg.engines
    }, null, 2))
    fs.chmodSync(filename, '444')
    callback(null)
  }
], true)

==> apeman-scff-react-2.0.47.tgz: package/ci/tmplify.js <==
#!/usr/bin/env node

/**
 * Tmplify prototype.
 */

'use strict'

process.chdir(`${__dirname}/..`)

const path = require('path')
const fs = require('fs')
const { runTasks } = require('ape-tasking')
const tmplconv = require('tmplconv')

const scaffold = require('../lib')

let demoPkgPath = require.resolve('apeman-demo-react/package.json')
let demoPkg = require(demoPkgPath)
let demo = path.dirname(demoPkgPath)

runTasks('tmplify', [
  () => tmplconv.tmplify(demo, 'asset/tmpl', {
    clean: true,
    mode: '444',
    pattern: [
      '+(bin|lib|test)/.*.bud',
      '+(bin|lib|test)/.*.hbs',
      'test/._test.js.bud',
      'doc/demo/.*.*',
      '**/*.*',
      '.*'
    ],
    ignore: [
      '.DS_Store',
      '.svn',
      '.npmignore',
      '.gitignore',
      'node_modules/**/*.*',
      'node_modules/**/.*',
      'doc/demo/demo.html',
      'doc/demo/demo.js',
      'ci/demo.js',
      'lib/index.js',
      'lib/*.js',
      'README.md',
      'LICENSE'
    ],
    data: {
      'github_repository': 'apeman-demo-labo/apeman-demo-react',
      'package_name': demoPkg.name,
      'package_description': demoPkg.description,
      'component_name': 'DemoComponent',
      'author_name': demoPkg.author.name,
      'author_email': demoPkg.author.email,
      'author_url': demoPkg.author.url
    },
    prefix: scaffold.prefix,
    suffix: scaffold.suffix
  }),
  () => tmplconv.tmplify(__dirname + '/..', 'asset/tmpl', {
    pattern: [
      '.gitignore',
      '.npmignore'
    ],
    prefix: scaffold.prefix,
    suffix: scaffold.suffix
  }),
  (callback) => {
    let filename = require.resolve('../asset/tmpl/package.json.tmpl')
    let str = fs.readFileSync(filename).toString()
    let pkg = JSON.parse(str)
    fs.chmodSync(filename, '644')
    fs.writeFileSync(filename, JSON.stringify({
      name: pkg.name,
      version: '1.0.0',
      description: pkg.description,
      main: pkg.main,
      scripts: pkg.scripts,
      repository: pkg.repository.url.split(/\//g).slice(-1).join('/').replace(/\.git$/, ''),
      keywords: pkg.keywords,
      author: pkg.author,
      license: pkg.license,
      bugs: pkg.bugs,
      homepage: pkg.homepage,
      dependencies: pkg.dependencies,
      devDependencies: pkg.devDependencies,
      engines: pkg.engines
    }, null, 2))
    fs.chmodSync(filename, '444')
    callback(null)
  }
], true)
